def full_name(first_name,last_name):
    return f"Hello {first_name}  {last_name}"
message = full_name("Betrand ", "Mutagha ")
print(message)
if message == message:
    print(" yes ")
elif message != message:
    print("No")
else:
    print("All wrong")
