<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <title>Client Cloud Readiness Assessment</title>
    <link
      rel="stylesheet"
      href="{{ url_for('static', filename='css/assessment.css') }}"
    />
  </head>
  <body>
    <div class="container">
      <h1>Cloud Readiness Assessment</h1>

      <form method="POST">
        <label for="client_name">Client Name:</label>
        <input type="text" name="client_name" id="client_name" required />

        <label for="score">Readiness Score (0–100):</label>
        <input type="number" name="score" id="score" required />

        <button type="submit">Assess</button>
      </form>

      {% if result %}
      <div class="result">
        <h2>Assessment Result:</h2>
        <p>{{ result }}</p>
      </div>
      {% endif %}
    </div>
  </body>
</html>
