{% extends "base.html" %}

{% block main %}
<div class="container">
    <div class="row">
        {% for video in videos %}
        <div class="col-md-4">
            <div class="card mb-4 shadow-sm">
                <video width="100%" controls>
                    <source src="{{ video }}" type="video/mp4">
                    Your browser does not support the video tag.
                </video>
           
            </div>
        </div>
        {% endfor %}
    </div>
</div>

{% endblock main %}